/*
** Module   : SimpleInitializer.java
** Abstract : Initializes something using the same instance, repeatedly.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 GES 20130203 Created initial version.
*/

package com.goldencode.expr;

/**
 * Generates an initial value for a variable, using a contained instance
 * that is returned directly.
 */
public class SimpleInitializer
extends Initializer
{
   /** The instance used as the initial value. */
   private Object instance = null;
   
   /**
    * Construct an instance.
    *
    * @param    instance
    *           The object to be used as the initial value.
    */
   public SimpleInitializer(Object instance)
   {
      this.instance = instance;
   }
   
   /**
    * Evaluate the initializer and return back the result.
    *
    * @return   The initial value.
    */
   public Object resolve()
   {
      return instance;
   }

   /**
    * Report the type of object which will be returned when {@link #resolve}
    * is called.
    *
    * @return   The value's return type.
    */
   public Class<?> getReturnType()
   {
      return instance.getClass();
   }
}
